==> qlcplus_4.12.2.orig.tar.xz: qlcplus-QLC-_4.12.2/plugins/gpio/GPIO_it_IT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>GPIOConfiguration</name>
    <message>
        <location filename="gpioconfiguration.ui" line="14"/>
        <source>Configure GPIO Plugin</source>
        <translation>Configurazione plugin GPIO</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.ui" line="28"/>
        <source>GPIO Number</source>
        <translation>Numero del GPIO</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.ui" line="33"/>
        <source>Usage</source>
        <translation>Utilizzo</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.cpp" line="57"/>
        <source>Not used</source>
        <translation>Non utilizzato</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.cpp" line="58"/>
        <source>Input</source>
        <translation>Ingresso</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.cpp" line="59"/>
        <source>Output</source>
        <translation>Uscita</translation>
    </message>
</context>
<context>
    <name>GPIOPlugin</name>
    <message>
        <location filename="gpioplugin.cpp" line="84"/>
        <source>This plugin provides input/output on GPIO PINs.</source>
        <translation>Questa plugin permette trasmissione/ricezione di dati su PIN GPIO.</translation>
    </message>
</context>
</TS>

==> qlcplus_4.14.3.orig.tar.xz: qlcplus-QLC-_4.14.3/plugins/gpio/GPIO_it_IT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>GPIOConfiguration</name>
    <message>
        <location filename="gpioconfiguration.ui" line="33"/>
        <source>Configure GPIO Plugin</source>
        <translation>Configurazione plugin GPIO</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.ui" line="46"/>
        <source>Selected chip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gpioconfiguration.ui" line="57"/>
        <source>GPIO Number</source>
        <translation>Numero del GPIO</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.ui" line="62"/>
        <source>Usage</source>
        <translation>Utilizzo</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.ui" line="67"/>
        <source>Channel number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gpioconfiguration.cpp" line="79"/>
        <source>Not used</source>
        <translation>Non utilizzato</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.cpp" line="80"/>
        <source>Input</source>
        <translation>Ingresso</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.cpp" line="81"/>
        <source>Output</source>
        <translation>Uscita</translation>
    </message>
</context>
<context>
    <name>GPIOPlugin</name>
    <message>
        <location filename="gpioplugin.cpp" line="97"/>
        <source>This plugin provides input/output on GPIO PINs.</source>
        <translation>Questa plugin permette trasmissione/ricezione di dati su PIN GPIO.</translation>
    </message>
</context>
</TS>
